@@ -22,29 +22,29 @@
  * */
 
 static gchar *info_text[] = {
-  "<b>GKrellM Radio Plugin\n\n",
-  "This plugin allow you to control the radio card of your Linux box,\
-   if you have one installed.\n",
-  "<b>\nUser Interface:\n",
-  "\n\t* Clicking the right button will turn the radio on and off.\n",
-  "\t* Clicking the left text will tune to the next channel configured",
-  " under configuration.\n"
-  "\t* Using your mousewheel will tune up or down.\n",
-  "\t*Right mouse button will pop up a channel menu\n",
-  "<b>\nThanks to:\n",
-  "\n\tLars Christensen - Upstream author untill version 0.2.1\n",
-  "\tGerd Knorr - borrowed some of the radio interface code from his Xawtv",
-  " radio application.\n",
-  "<b>\nHomepage:\n",
+  N_("<b>GKrellM Radio Plugin\n\n"),
+  N_("This plugin allow you to control the radio card of your Linux box," \
+   "if you have one installed.\n"),
+  N_("<b>\nUser Interface:\n"),
+  N_("\n\t* Clicking the right button will turn the radio on and off.\n"),
+  N_("\t* Clicking the left text will tune to the next channel configured" \
+  " under configuration.\n"),
+  N_("\t* Using your mousewheel will tune up or down.\n"),
+  N_("\t*Right mouse button will pop up a channel menu\n"),
+  N_("<b>\nThanks to:\n"),
+  N_("\n\tLars Christensen - Upstream author untill version 0.2.1\n" \
+  "\tGerd Knorr - borrowed some of the radio interface code from his Xawtv" \
+  " radio application.\n"),
+  N_("<b>\nHomepage:\n"),
   "\n\thttp://gkrellm.luon.net/gkrellm-radio.phtml\n"
 };
 
-static Panel    *panel;
-static Monitor  *plugin_monitor;
+static GkrellmPanel    *panel;
+static GkrellmMonitor  *plugin_monitor;
 
-static Decal *station_text, *decal_onoff_pix;
+static GkrellmDecal *station_text, *decal_onoff_pix;
 
-DecalButton *onoff_button;
+GkrellmDecalbutton *onoff_button;
 
 static gint     style_id;
 
@@ -112,13 +112,15 @@ void start_mute_timer() {
 
 void 
 do_switch_station(int nr) {
+  gchar *text_utf8 = NULL, *text_locale = NULL;
   nr %= nstations;
   currentstation = nr;
   start_mute_timer();
   radio_tune(stations[nr].freq);
+  gkrellm_locale_dup_string(&text_utf8, stations[nr].station_name, &text_locale);
   gkrellm_draw_decal_text(panel, station_text, 
-      stations[nr].station_name, -1);
-  gkrellm_draw_layers_force(panel);
+      text_locale, -1);
+  gkrellm_draw_panel_layers(panel);
 }
 
 static void exit_func(void) {
@@ -139,6 +141,10 @@ create_freq_menu(void) {
   if (menu != NULL) {
     gtk_widget_destroy(menu);
   }
+  if (!nstations) { 
+    menu = NULL;
+    return;
+  }
     
   menu = gtk_menu_new();
 
@@ -171,57 +177,57 @@ void set_onoff_button(int on) {
   else
     imgid = D_MISC_BUTTON_OUT;
   gkrellm_set_decal_button_index(onoff_button, imgid);
+  gkrellm_draw_panel_layers(panel);
 }
 
 void reopen_radio() {
   if (!attempt_reopen) return;
 
   if (open_radio() != -1) {
-    if (radio_ismute()) {
-      close_radio();
-      onoff_state = 0;		/* off */
-    } else {
       start_mute_timer();
+      radio_tune(current_freq());
+      set_text_freq(current_freq());
       onoff_state = 1;		/* on */
-    }
   }
   set_onoff_button(onoff_state);
 }
 
 void gkrellm_radio_turn_onoff(void) {
-    onoff_state = !onoff_state;
-    if (onoff_state) {
+    if (!onoff_state) {  
       if (open_radio() == -1) {
-        	gkrellm_message_window("GKrellM error",
-			      "GKrellM radio plugin couldn't open /dev/radio", NULL);
+        	gkrellm_message_window("GKrellM radio plugin",
+			      _("Couldn't open /dev/radio"), NULL);
       } else {
 	    /* radio was opened */
+        onoff_state = 1; /* on */
       	start_mute_timer();
       	radio_tune(current_freq());
         set_text_freq(current_freq());
        	set_onoff_button(onoff_state);
       }
     } else {
+      onoff_state = 0; /* off */
       set_onoff_button(onoff_state);
       close_radio();
     }
 }
 
 void
-cb_button(DecalButton *button)
+cb_button(GkrellmDecalbutton *button)
 {
   if (GPOINTER_TO_INT(button->data) == 1) { switch_station(); }
   if (GPOINTER_TO_INT(button->data) == 2) { gkrellm_radio_turn_onoff(); }
 }
 
 static void set_text_freq(float freq) {
-  gkrellm_draw_decal_text(panel, station_text, station_name(freq), -1);
-  gkrellm_draw_layers_force(panel);
+  gchar *text_utf8 = NULL, *text_locale = NULL;
+  gkrellm_locale_dup_string(&text_utf8, station_name(freq), &text_locale);
+  gkrellm_draw_decal_text(panel, station_text, text_locale, -1);
+  gkrellm_draw_panel_layers(panel);
 }
 
 static gint
-panel_expose_event(GtkWidget *widget, GdkEventExpose *ev)
-{
+panel_expose_event(GtkWidget *widget, GdkEventExpose *ev) {
   gdk_draw_pixmap(widget->window,
 		  widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
 		  panel->pixmap, ev->area.x, ev->area.y, ev->area.x, ev->area.y,
@@ -238,35 +244,31 @@ void gkrellm_radio_finetune_delta (float amount) {
 static gint 
 button_release_event(GtkWidget *widget, GdkEventButton *ev, void *N) {
 
-  switch (ev->button) {
-    case 3:
-      gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
-          ev->state, ev->time);
-      break;
-    case 4:
-      gkrellm_radio_finetune_delta(+0.05);
-      break;
-    case 5:
-      gkrellm_radio_finetune_delta(-0.05);
-      break; 
+  if  (ev->button == 3) {
+    if (menu == NULL) gkrellm_message_window("GKrellM radio plugin",
+        _("Please setup some channels in the configuration"),NULL);
+    else gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL,
+        ev->state, ev->time);
   }
   return TRUE;
 }
 
-static void
-update_plugin()
-{
-  gkrellm_draw_layers(panel);
+static gint scroll_event(GtkWidget *widget,GdkEventScroll *ev,gpointer data) {
+  float delta = ev->direction == GDK_SCROLL_UP ? 0.05 : -0.05;
+  gkrellm_radio_finetune_delta(delta);
+  return TRUE;
 }
 
 static void
 create_plugin(GtkWidget *vbox, gint first_create) {
-  Style           *style;
-  TextStyle       *ts, *ts_alt;
+  GkrellmStyle     *style;
+  GkrellmTextstyle *ts, *ts_alt;
+  GkrellmMargin    *margin;
   GdkPixmap       *pixmap;
   GdkBitmap       *mask;
   gint            y;
   gint            x;
+  gchar *text_utf8 = NULL, *text_locale = NULL;
 
   if (first_create) {
     panel = gkrellm_panel_new0();
@@ -278,7 +280,7 @@ create_plugin(GtkWidget *vbox, gint first_create) {
 
   style = gkrellm_meter_style(style_id);
 
-  /* Each Style has two text styles.  The theme designer has picked the
+  /* Each GkrellmStyle has two text styles.  The theme designer has picked the
      |  colors and font sizes, presumably based on knowledge of what you draw
      |  on your panel.  You just do the drawing.  You probably could assume
      |  the ts font is larger than the ts_alt font, but again you can be
@@ -289,7 +291,7 @@ create_plugin(GtkWidget *vbox, gint first_create) {
   panel->textstyle = ts;      /* would be used for a panel label */
 
   y = 2;			/* some border */
-  station_text = gkrellm_create_decal_text(panel, "Hello World", ts_alt, style, 2, y, 40);
+  station_text = gkrellm_create_decal_text(panel, _("Hello World"), ts_alt, style, 2, y, 40);
 
   /* Create a pixmap decal and place it to the right of station_text.  Use
      |  decals from the builtin decal_misc.xpm.
@@ -304,10 +306,8 @@ create_plugin(GtkWidget *vbox, gint first_create) {
   /* Configure the panel to hold the above created decals, add in a little
      |  bottom margin for looks, and create the panel.
   */
-  gkrellm_configure_panel(panel, NULL, style);
-  panel->label->h_panel += 2;     /* Some bottom margin */
-  gkrellm_create_panel(vbox, panel, gkrellm_bg_meter_image(style_id));
-  gkrellm_monitor_height_adjust(panel->h);
+  gkrellm_panel_configure(panel, NULL, style);
+  gkrellm_panel_create(vbox, plugin_monitor,panel);
 
   /* After the panel is created, the decals can be converted into buttons.
      |  First draw the initial text into the text decal button and then
@@ -316,11 +316,13 @@ create_plugin(GtkWidget *vbox, gint first_create) {
      |  decal.  Just pass the frame we want to be the out image and the
      |  frame for the in or pressed image.
   */
-  gkrellm_draw_decal_text(panel, station_text, station_name(current_freq()),
+  gkrellm_locale_dup_string(&text_utf8, station_name(current_freq()), &text_locale);
+  gkrellm_draw_decal_text(panel, station_text, text_locale,
 			  button_state);
 
+  margin = gkrellm_get_style_margins(style);
   gkrellm_put_decal_in_meter_button(panel, station_text, cb_button,
-				    GINT_TO_POINTER(1));
+				    GINT_TO_POINTER(1),margin);
   onoff_button = 
     gkrellm_make_decal_button(panel, decal_onoff_pix, cb_button,
 			      GINT_TO_POINTER(2),
@@ -334,13 +336,16 @@ create_plugin(GtkWidget *vbox, gint first_create) {
   */
 
   if (first_create) {
-    gtk_signal_connect(GTK_OBJECT (panel->drawing_area), "expose_event",
+    g_signal_connect(GTK_OBJECT (panel->drawing_area), "expose_event",
 		       (GtkSignalFunc) panel_expose_event, NULL);
-    gtk_signal_connect(GTK_OBJECT (panel->drawing_area), "button_release_event",
+    g_signal_connect(GTK_OBJECT (panel->drawing_area), "button_release_event",
 		       GTK_SIGNAL_FUNC(button_release_event), NULL);
+    g_signal_connect(GTK_OBJECT (panel->drawing_area), "scroll_event",
+		       GTK_SIGNAL_FUNC(scroll_event), NULL);
+    reopen_radio();
   }
   
-  reopen_radio();
+  gkrellm_draw_panel_layers(panel);
 }
 
 static GtkWidget *gui_station_list = NULL;
@@ -365,7 +370,7 @@ void close_and_add_station_editor(gpointer *userdata) {
   gfloat freq;
   gchar fstr[32];
 
-  f[0] = gtk_entry_get_text(GTK_ENTRY(gui_station_name_input));
+  f[0] = (gchar *) gtk_entry_get_text(GTK_ENTRY(gui_station_name_input));
   freq = gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(gui_freq_input));
   sprintf(fstr, "%.2f", freq);
   f[1] = fstr;
@@ -400,13 +405,13 @@ void create_station_editor(gint new_entry) {
   
   table = gtk_table_new(2, 2, 0);
   
-  label = gtk_label_new("Station Name:");
+  label = gtk_label_new(_("Station Name:"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, GTK_EXPAND, GTK_FILL, 4, 4);
   
   gui_station_name_input = gtk_entry_new();
   gtk_table_attach(GTK_TABLE(table), gui_station_name_input, 1, 2, 0, 1, GTK_EXPAND, GTK_FILL, 4, 4);
 
-  label = gtk_label_new("Frequency:");
+  label = gtk_label_new(_("Frequency:"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, GTK_EXPAND, GTK_FILL, 4, 4);
   
   adj = gtk_adjustment_new(current_freq(), 0.05, 999.99, 0.05, 1, 1);
@@ -422,8 +427,8 @@ void create_station_editor(gint new_entry) {
 			    (gpointer)new_entry);
   gtk_container_add(action_area, button);
 
-  /* Cancel Button */
-  button = gtk_button_new_with_label("Cancel");
+  /* Cancel button */
+  button = gtk_button_new_with_label(_("Cancel"));
   gtk_signal_connect_object (GTK_OBJECT(button), "clicked",
 			     GTK_SIGNAL_FUNC(close_station_editor), NULL);
 
@@ -494,7 +499,7 @@ static void create_config(GtkWidget *tab) {
   GtkWidget *text, *label, *panel, *button, *hbox, *scrolled, *frame, *vbox;
   GtkObject *adj;
   gchar *plugin_about_text;
-  gchar *station_tab_titles[3] = { "Station", "Frequency", "" };
+  gchar *station_tab_titles[3] = { _("Station"), _("Frequency"), "" };
   char *f[3];
   int i;
 
@@ -539,28 +544,28 @@ static void create_config(GtkWidget *tab) {
 
   hbox = gtk_hbox_new(0, 0);
 
-  button = gtk_button_new_with_label("New");
+  button = gtk_button_new_with_label(_("New"));
   gtk_signal_connect(GTK_OBJECT(button), "clicked", (GtkSignalFunc)gui_new_station, NULL);
 
   gtk_box_pack_start(GTK_BOX(hbox), button, 0, 0, 2);
-  button = gtk_button_new_with_label("Edit"); 
+  button = gtk_button_new_with_label(_("Edit")); 
   gtk_signal_connect(GTK_OBJECT(button), "clicked", (GtkSignalFunc)gui_edit_station, NULL);
 
   gtk_box_pack_start(GTK_BOX(hbox), button, 0, 0, 2);
-  button = gtk_button_new_with_label("Delete"); 
+  button = gtk_button_new_with_label(_("Delete")); 
   gtk_signal_connect(GTK_OBJECT(button), "clicked", (GtkSignalFunc)gui_delete_station, NULL);
 
   gtk_box_pack_start(GTK_BOX(hbox), button, 0, 0, 2);
-  button = gtk_button_new_with_label("Up");
+  button = gtk_button_new_with_label(_("Up"));
   gtk_signal_connect(GTK_OBJECT(button), "clicked", (GtkSignalFunc)gui_moveup_station, NULL);
 
   gtk_box_pack_start(GTK_BOX(hbox), button, 0, 0, 2);
 
-  button = gtk_button_new_with_label("Down");
+  button = gtk_button_new_with_label(_("Down"));
   gtk_signal_connect(GTK_OBJECT(button), "clicked", (GtkSignalFunc)gui_movedown_station, NULL);
   gtk_box_pack_start(GTK_BOX(hbox), button, 0, 0, 2);
   
-  label = gtk_label_new("Stations");
+  label = gtk_label_new(_("Stations"));
 
   gtk_box_pack_start(GTK_BOX(panel), hbox, FALSE, FALSE, 4);
 
@@ -577,7 +582,7 @@ static void create_config(GtkWidget *tab) {
     hbox = gtk_hbox_new(0, 0);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, 0, 0, 2);
     
-    label = gtk_label_new("Time to mute on channel jump (seconds):");
+    label = gtk_label_new(_("Time to mute on channel jump (seconds):"));
     gtk_box_pack_start(GTK_BOX(hbox), label, 0, 0, 2);
     
     adj = gtk_adjustment_new(mutetime, 0.0, 9.99, 0.01, 0.1, 1);
@@ -589,50 +594,42 @@ static void create_config(GtkWidget *tab) {
 
   /* reopenoption */ {
 
-    gui_reopen_toggle = gtk_check_button_new_with_label("Attempt to reopen radio on startup");
+    gui_reopen_toggle = gtk_check_button_new_with_label(_("Attempt to reopen radio on startup"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gui_reopen_toggle), attempt_reopen);
     gtk_box_pack_start(GTK_BOX(vbox), gui_reopen_toggle, 0, 0, 2);
   /* close radio on exit toggle */
     gui_close_toggle = 
-      gtk_check_button_new_with_label("Turn radio off when exiting gkrellm");
+      gtk_check_button_new_with_label(_("Turn radio off when exiting gkrellm"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gui_close_toggle), 
         close_atexit);
     gtk_box_pack_start(GTK_BOX(vbox), gui_close_toggle, 0, 0, 2);
 
   }
   
-  label = gtk_label_new("Options");
+  label = gtk_label_new(_("Options"));
   gtk_notebook_append_page(GTK_NOTEBOOK(tabs), vbox, label);
 
   /* INFO TAB */
   
   frame = gtk_frame_new(NULL);
-  gtk_container_border_width(GTK_CONTAINER(frame), 3);
-  scrolled = gtk_scrolled_window_new(NULL, NULL);
-  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
-				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_container_add(GTK_CONTAINER(frame), scrolled);
-  label = gtk_label_new("Info");
-  gtk_notebook_append_page(GTK_NOTEBOOK(tabs), frame, label);
-  
-  text = gtk_text_new(NULL, NULL);
-  gtk_text_set_editable(GTK_TEXT(text), FALSE);
-
-  gkrellm_add_info_text(text,info_text,sizeof(info_text)/sizeof(gchar *));
-  gtk_container_add(GTK_CONTAINER(scrolled), text);
+  scrolled = gkrellm_gtk_notebook_page(tabs,_("Info"));
+  text = gkrellm_gtk_scrolled_text_view(scrolled,NULL,
+                                   GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 
+  for (i=0; i < sizeof(info_text)/sizeof(gchar *); ++i)
+     gkrellm_gtk_text_view_append(text, _(info_text[i]));
   /* ABOUT TAB */
 
   plugin_about_text = g_strdup_printf(
-   "Radio Plugin " VERSION "\n" \
+   _("Radio Plugin %s\n" \
    "GKrellM radio Plugin\n\n" \
    "Copyright (C) 2001-2002 Sjoerd Simons\n" \
    "sjoerd@luon.net\n" \
    "http://gkrellm.luon.net/gkrellm-radio.phtml\n\n" \
-   "Released under the GNU General Public Licence");
+   "Released under the GNU General Public Licence"), VERSION);
 
   text = gtk_label_new(plugin_about_text); 
-  label = gtk_label_new("About");
+  label = gtk_label_new(_("About"));
   gtk_notebook_append_page(GTK_NOTEBOOK(tabs),text,label);
   g_free(plugin_about_text);
 }
@@ -728,12 +725,12 @@ void load_config(gchar *s) {
 
 /* The monitor structure tells GKrellM how to call the plugin routines.
 */
-static Monitor  plugin_mon  =
+static GkrellmMonitor  plugin_mon  =
 {
   CONFIG_NAME,			/* Name, for config tab.    */
   0,				/* Id,  0 if a plugin       */
   create_plugin,		/* The create function      */
-  update_plugin,		/* The update function      */
+  NULL,		/* The update function      */
   create_config,		/* The config tab create function   */
   apply_config,			/* Apply the config function        */
 
@@ -755,9 +752,13 @@ static Monitor  plugin_mon  =
 /* All GKrellM plugins must have one global routine named init_plugin()
 |  which returns a pointer to a filled in monitor structure.
 */
-Monitor *
-init_plugin()
-{
+GkrellmMonitor *
+gkrellm_init_plugin() {
+
+#ifdef ENABLE_NLS
+   bind_textdomain_codeset(PACKAGE, "UTF-8");
+#endif /* ENABLE_NLS */
+
   style_id = gkrellm_add_meter_style(&plugin_mon, STYLE_NAME);
   plugin_monitor = &plugin_mon;
 #ifdef HAVE_LIRC
